# GPROF-NN

This Python package implements the GPROF-NN retrieval algorithms for the passive
microwave observations of GPM.

## Overview

This package provides a command line application, which implements the principal data preparation,
training and retrieval functionality of the retrieval. In addition to that, the ``gprof_nn`` python
package provides utility functions for the processing of GPM-related data.

## Installation

The package can be install using pip.

Because the package is still under development it is recommended to install it  from source.

````
git clone git@github.com:simonpf/gprof_nn
cd gprof_nn
pip install -e .
````
